@@ -1,19 +1,24 @@
 use clap::{Command, CommandFactory, Parser};
 use clap_complete::{generate, Generator, Shell};
 use std::io;
+use std::process::exit;
 
 #[derive(Parser)]
-#[command(name = "spin")]
+#[command(name = "tspin")]
 #[command(author, version, about)]
 pub struct Cli {
     /// Path to file or folder
     #[clap(name = "FILE")]
-    pub file_path: Option<String>,
+    pub file_or_folder_path: Option<String>,
 
     /// Follow (tail) the contents of the file
     #[clap(short = 'f', long = "follow")]
     pub follow: bool,
 
+    /// Start at the end of the file
+    #[clap(short = 't', long = "tail")]
+    pub tail: bool,
+
     /// Print the output to stdout
     #[clap(short = 'p', long = "print", conflicts_with = "follow")]
     pub to_stdout: bool,
@@ -26,21 +31,28 @@ pub struct Cli {
     #[clap(short = 'l', long = "follow-command", conflicts_with = "follow")]
     pub listen_command: Option<String>,
 
-    /// Generate a new configuration file
-    #[clap(long = "create-default-config")]
-    pub create_default_config: bool,
-
-    /// Print the default configuration
-    #[clap(long = "show-default-config", conflicts_with = "create_default_config")]
-    pub show_default_config: bool,
-
     /// Print completions to stdout
     #[clap(long = "z-generate-shell-completions", hide = true)]
     pub generate_shell_completions: Option<String>,
 }
 
-pub fn get_args() -> Cli {
-    Cli::parse()
+pub fn get_args_or_exit_early() -> Cli {
+    let args = Cli::parse();
+
+    if should_exit_early(&args) {
+        exit(0);
+    }
+
+    args
+}
+
+fn should_exit_early(args: &Cli) -> bool {
+    if args.generate_shell_completions.is_some() {
+        print_completions_to_stdout();
+        return true;
+    }
+
+    false
 }
 
 pub fn print_completions_to_stdout() {
