@@ -15,6 +15,7 @@ pub enum Fg {
     White,
     Magenta,
     Cyan,
+    Black,
     #[default]
     None,
 }
@@ -25,6 +26,7 @@ pub enum Bg {
     Green,
     Blue,
     Yellow,
+    Magenta,
     White,
     #[default]
     None,
@@ -46,14 +48,16 @@ pub fn to_ansi(style: &Style) -> String {
         Fg::White => Some("37"),
         Fg::Magenta => Some("35"),
         Fg::Cyan => Some("36"),
+        Fg::Black => Some("30"),
         Fg::None => None,
     };
 
     let bg_code = match style.bg {
         Bg::Red => Some("41"),
         Bg::Green => Some("42"),
-        Bg::Blue => Some("44"),
         Bg::Yellow => Some("43"),
+        Bg::Blue => Some("44"),
+        Bg::Magenta => Some("45"),
         Bg::White => Some("47"),
         Bg::None => None,
     };
@@ -67,11 +71,7 @@ pub fn to_ansi(style: &Style) -> String {
         bg_code,
     ];
 
-    let joined_codes = codes
-        .iter()
-        .filter_map(|&code| code)
-        .collect::<Vec<&str>>()
-        .join(";");
+    let joined_codes = codes.iter().filter_map(|&code| code).collect::<Vec<&str>>().join(";");
 
     format!("\x1b[{}m", joined_codes)
 }
@@ -88,6 +88,7 @@ impl FromStr for Fg {
             "magenta" => Ok(Fg::Magenta),
             "cyan" => Ok(Fg::Cyan),
             "white" => Ok(Fg::White),
+            "black" => Ok(Fg::Black),
             _ => Ok(Fg::None),
         }
     }
@@ -103,6 +104,7 @@ impl fmt::Display for Fg {
             Fg::Magenta => write!(f, "\x1b[35m"),
             Fg::Cyan => write!(f, "\x1b[36m"),
             Fg::White => write!(f, "\x1b[37m"),
+            Fg::Black => write!(f, "\x1b[30m"),
             Fg::None => write!(f, "\x1b[0m"),
         }
     }
@@ -127,16 +129,8 @@ impl<'de> Visitor<'de> for FgVisitor {
     }
 
     fn visit_str<E: de::Error>(self, v: &str) -> Result<Fg, E> {
-        let fg = v.parse().map_err(|_| E::custom("Parse error"))?;
-
-        match fg {
-            Fg::Red | Fg::Green | Fg::Blue | Fg::Yellow | Fg::Magenta | Fg::Cyan | Fg::White => {
-                Ok(fg)
-            }
-            _ => {
-                colored_panic("Invalid foreground color: ", v);
-            }
-        }
+        v.parse()
+            .map_err(|_| E::custom(format!("Invalid foreground color: {}", v)))
     }
 }
 
@@ -150,6 +144,7 @@ impl FromStr for Bg {
             "blue" => Ok(Bg::Blue),
             "yellow" => Ok(Bg::Yellow),
             "white" => Ok(Bg::White),
+            "magenta" => Ok(Bg::Magenta),
             _ => Ok(Bg::None),
         }
     }
@@ -174,27 +169,7 @@ impl<'de> Visitor<'de> for BgVisitor {
     }
 
     fn visit_str<E: de::Error>(self, v: &str) -> Result<Bg, E> {
-        let bg = v.parse().map_err(|_| {
-            colored_panic("Parse error", &format!("Invalid background color: {}", v))
-        })?;
-
-        match bg {
-            Bg::Red | Bg::Green | Bg::Blue | Bg::Yellow | Bg::White => Ok(bg),
-            _ => {
-                colored_panic("Invalid background color: ", v);
-            }
-        }
+        v.parse()
+            .map_err(|_| E::custom(format!("Invalid background color: {}", v)))
     }
 }
-
-fn colored_panic(message: &str, invalid_value: &str) -> ! {
-    let color_yellow: &str = "\x1b[33m";
-    let color_reset: &str = "\x1b[0m";
-
-    let colored_message = format!(
-        "{}{}{}{}",
-        message, color_yellow, invalid_value, color_reset,
-    );
-    eprintln!("{}", colored_message);
-    std::process::exit(1);
-}
