@@ -1,7 +1,14 @@
+use crate::line_info::LineInfo;
+
 pub const OK: i32 = 0;
 pub const GENERAL_ERROR: i32 = 1;
 pub const MISUSE_SHELL_BUILTIN: i32 = 2;
 
+pub trait Highlight {
+    fn should_short_circuit(&self, line_info: &LineInfo) -> bool;
+    fn apply(&self, input: &str) -> String;
+}
+
 pub struct Error {
     pub exit_code: i32,
     pub message: String,
@@ -11,6 +18,7 @@ pub struct Config {
     pub input: Input,
     pub output: Output,
     pub follow: bool,
+    pub tail: bool,
 }
 
 pub struct PathAndLineCount {
